@@ -1,20 +1,16 @@
 #
 # This file is part of Dancer-Plugin-Browser
 #
-# This software is copyright (c) 2014 by Natal Ngétal.
+# This software is copyright (c) 2016 by Natal Ngétal.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
 package Dancer2::Plugin::BrowserDetect;
-{
-  $Dancer2::Plugin::BrowserDetect::VERSION = '1.141180';
-}
-
+$Dancer2::Plugin::BrowserDetect::VERSION = '1.160190';
 use strict;
 use warnings;
 
-use Dancer2 ':syntax';
 use Dancer2::Plugin;
 
 use HTTP::BrowserDetect;
@@ -22,24 +18,33 @@ use HTTP::BrowserDetect;
 #ABSTRACT: Provides an easy to have info of the browser.
 
 
-hook before_template => sub {
-    my $tokens = shift;
-
-    $tokens->{browser_detect} = _browser_detect();
+on_plugin_import {
+    my $dsl = shift;
+    $dsl->app->add_hook(
+        Dancer2::Core::Hook->new(
+            name => 'before_template',
+            code => sub {
+                my $tokens = shift;
+                $tokens->{browser_detect} = _browser_detect($dsl);
+            },
+        )
+    );
 };
 
 register browser_detect => sub {
-    _browser_detect();
+    my $dsl = shift;
+    _browser_detect($dsl);
 };
 
 sub _browser_detect {
-    my $useragent = request->env->{HTTP_USER_AGENT};
+    my $dsl = shift;
+    my $useragent = $dsl->app->request->env->{HTTP_USER_AGENT};
     my $browser   = HTTP::BrowserDetect->new($useragent);
 
     return $browser;
 }
 
-register_plugin for_versions => [2];
+register_plugin;
 
 
 1;
@@ -48,13 +53,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dancer2::Plugin::BrowserDetect - Provides an easy to have info of the browser.
 
 =head1 VERSION
 
-version 1.141180
+version 1.160190
 
 =head1 SYNOPSIS
 
@@ -89,8 +96,6 @@ To have info of the browser
     input: none
     output: A HTTP::BrowserDetect object
 
-=encoding utf8
-
 =head1 CONTRIBUTING
 
 This module is developed on Github at:
@@ -123,7 +128,7 @@ Natal Ngétal
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Natal Ngétal.
+This software is copyright (c) 2016 by Natal Ngétal.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
